
.. Copyright BigchainDB GmbH and BigchainDB contributors
   SPDX-License-Identifier: (Apache-2.0 AND CC-BY-4.0)
   Code is Apache-2.0 and docs are CC-BY-4.0

=======
Credits
=======

Development Lead
----------------

* BigchainDB <dev@bigchaindb.com>

Contributors
------------

None yet. Why not be the first?
